"""Setup script for the nyan-pytest package."""

from setuptools import setup

if __name__ == "__main__":
    # This file is provided for compatibility with older Python versions/tools
    # The actual configuration is in pyproject.toml
    setup()